{% set cvss = cve.json.impact.baseMetricV2.cvssV2 %}
<div class="row">
    <div class="col-md-4">
        <div class="small-box {{ cvss_bg(cvss.baseScore)[0] }}">
            <div class="inner">
                <h3>{{ cvss.baseScore }}<sup style="font-size: 20px"> /10</sup></h3>
                <p>CVSS v2.0 : {{ cve.json.impact.baseMetricV2.severity }}</p>
            </div>
            <div class="icon">
                <i class="ion ion-stats-bars"></i>
            </div>
            <a href="https://www.first.org/cvss/v2/guide" target="_blank" class="small-box-footer">
                V2 Legend <i class="fa fa-arrow-circle-right"></i>
            </a>
        </div>

        <p><strong>Vector :</strong> {{ cvss.vectorString }}</p>
        <p><strong>Exploitability :</strong> {{ cve.json.impact.baseMetricV2.exploitabilityScore }} / <strong>Impact
            :</strong> {{ cve.json.impact.baseMetricV2.impactScore }}</p>
    </div>

    <div class="col-md-4">
        <div class="panel-group panel-group-cvss">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h4 class="panel-title">
                        Access Vector
                        <span class="pull-right label {{ metric_bg('v2', 'AV', cvss.accessVector) }}">{{ cvss.accessVector }}</span>
                    </h4>
                </div>
            </div>
        </div>
        <div class="panel-group panel-group-cvss">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h4 class="panel-title">
                        Access Complexity
                        <span class="pull-right label {{ metric_bg('v2', 'AC', cvss.accessComplexity) }}">{{ cvss.accessComplexity }}</span>
                    </h4>
                </div>
            </div>
        </div>
        <div class="panel-group panel-group-cvss">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h4 class="panel-title">
                        Authentication
                        <span class="pull-right label {{ metric_bg('v2', 'AU', cvss.authentication) }}">{{ cvss.authentication }}</span>
                    </h4>
                </div>
            </div>
        </div>
    </div>
    <div class="col-md-4">
        <div class="panel-group panel-group-cvss">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h4 class="panel-title">
                        Confidentiality Impact
                        <span class="pull-right label {{ metric_bg('v2', 'C', cvss.confidentialityImpact) }}">{{ cvss.confidentialityImpact }}</span>
                    </h4>
                </div>
            </div>
        </div>
        <div class="panel-group panel-group-cvss">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h4 class="panel-title">
                        Integrity Impact
                        <span class="pull-right label {{ metric_bg('v2', 'I', cvss.integrityImpact) }}">{{ cvss.integrityImpact }}</span>
                    </h4>
                </div>
            </div>
        </div>
        <div class="panel-group panel-group-cvss">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h4 class="panel-title">
                        Availability Impact
                        <span class="pull-right label {{ metric_bg('v2', 'A', cvss.availabilityImpact) }}">{{ cvss.availabilityImpact }}</span>
                    </h4>
                </div>
            </div>
        </div>
    </div>
</div>