{% extends "profiles/settings.html" %}

{% block title %}Edit Profile - {{ super() }}{% endblock %}

{% block content_settings %}
{% from "flask_user/_macros.html" import render_field, render_submit_field %}

<div class="box box-primary">
    <div class="box-header with-border">
        <h3 class="box-title">Edit Profile</h3>
    </div>
    <div class="box-body">
        <form action="" method="POST" class="form" role="form">
            {{ form.hidden_tag() }}
            {% for field in form %}
                {% if not field.flags.hidden %}
                    {% if field.type!='SubmitField' %}
                        {{ render_field(field, tabindex=loop.index*10) }}
                    {% endif %}
                {% endif %}
            {% endfor %}
            {{ render_submit_field(form.submit, tabindex=100) }}
        </form>
    </div>
</div>

{% endblock %}