{% extends 'base_blank.html' %}

{% block content %}
{% from "_macros.html" import render_field  %}
{% from "flask_user/_macros.html" import render_submit_field %}

<div class="login-box">
    <div class="login-box-body">
        <div class="login-logo">
            <img src="{{ url_for('static', filename='img/logo_full_48.png') }}" alt="Logo">
            <a href="{{ url_for('main.home') }}">OpenCVE.io</a>
        </div>
        {% include 'flash_messages.html' %}
        <p class="login-box-msg"><strong>Enter your email address below to receive a new confirmation link.</strong></p>
        <form action="" method="POST" class="form" role="form">
            {{ form.hidden_tag() }}
            {{ render_field(form.email, placeholder='Email', tabindex=10) }}
            <button type="submit" class="btn btn-primary btn-block btn-flat">Resend confirmation email</button>
        </form>
        <p>&nbsp;</p>
        <p class="center">
            Your account is already confirmed? <a href="{{ url_for('user.login') }}"> Sign in</a>
        </p>
    </div>
</div>

{% endblock %}