{% extends "profiles/settings.html" %}

{% block title %}Change password - {{ super() }}{% endblock %}

{% block content_settings %}
{% from "flask_user/_macros.html" import render_field, render_submit_field %}


<div class="box box-primary">
    <div class="box-header with-border">
        <h3 class="box-title">Change Password</h3>
    </div>
    <div class="box-body">
    <form action="" method="POST" class="form" role="form">
        {{ form.hidden_tag() }}
        {{ render_field(form.old_password, tabindex=10) }}
        {{ render_field(form.new_password, tabindex=20) }}
        {% if user_manager.USER_REQUIRE_RETYPE_PASSWORD %}
            {{ render_field(form.retype_password, tabindex=30) }}
        {% endif %}
        {{ render_submit_field(form.submit, tabindex=90) }}
    </form>
</div>

{% endblock %}
