{% set cvss = cve.json.impact.baseMetricV3.cvssV3 %}
<div class="row">
    <div class="col-md-4">
        <div class="small-box {{ cvss_bg(cvss.baseScore)[0] }}">
            <div class="inner">
                <h3>{{ cvss.baseScore }}<sup style="font-size: 20px"> /10</sup></h3>
                <p>CVSS v3.0 : {{ cvss.baseSeverity }}</p>
            </div>
            <div class="icon">
                <i class="ion ion-stats-bars"></i>
            </div>
            <a href="https://www.first.org/cvss/specification-document" target="_blank" class="small-box-footer">
                V3 Legend <i class="fa fa-arrow-circle-right"></i>
            </a>
        </div>

        <p><strong>Vector :</strong> {{ cvss.vectorString.split("0/")[1] }}</p>
        <p><strong>Exploitability :</strong> {{ cve.json.impact.baseMetricV3.exploitabilityScore }} / <strong>Impact
            :</strong> {{ cve.json.impact.baseMetricV3.impactScore }}</p>
    </div>

    <div class="col-md-4">
        <div class="panel-group panel-group-cvss">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h4 class="panel-title">
                        Attack Vector
                        <span class="pull-right label {{ metric_bg('v3', 'AV', cvss.attackVector) }}">{{ cvss.attackVector }}</span>
                    </h4>
                </div>
            </div>
        </div>
        <div class="panel-group panel-group-cvss">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h4 class="panel-title">
                        Attack Complexity
                        <span class="pull-right label {{ metric_bg('v3', 'AC', cvss.attackComplexity) }}">{{ cvss.attackComplexity }}</span>
                    </h4>
                </div>
            </div>
        </div>
        <div class="panel-group panel-group-cvss">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h4 class="panel-title">
                        Privileges Required
                        <span class="pull-right label {{ metric_bg('v3', 'PR', cvss.privilegesRequired) }}">{{ cvss.privilegesRequired }}</span>
                    </h4>
                </div>
            </div>
        </div>
        <div class="panel-group panel-group-cvss">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h4 class="panel-title">
                        User Interaction
                        <span class="pull-right label {{ metric_bg('v3', 'UI', cvss.userInteraction) }}">{{ cvss.userInteraction }}</span>
                    </h4>
                </div>
            </div>
        </div>
    </div>
    <div class="col-md-4">
        <div class="panel-group panel-group-cvss">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h4 class="panel-title">
                        Confidentiality Impact
                        <span class="pull-right label {{ metric_bg('v3', 'C', cvss.confidentialityImpact) }}">{{ cvss.confidentialityImpact }}</span>
                    </h4>
                </div>
            </div>
        </div>
        <div class="panel-group panel-group-cvss">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h4 class="panel-title">
                        Integrity Impact
                        <span class="pull-right label {{ metric_bg('v3', 'I', cvss.integrityImpact) }}">{{ cvss.integrityImpact }}</span>
                    </h4>
                </div>
            </div>
        </div>
        <div class="panel-group panel-group-cvss">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h4 class="panel-title">
                        Availability Impact
                        <span class="pull-right label {{ metric_bg('v3', 'A', cvss.availabilityImpact) }}">{{ cvss.availabilityImpact }}</span>
                    </h4>
                </div>
            </div>
        </div>
        <div class="panel-group panel-group-cvss">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h4 class="panel-title">
                        Scope
                        <span class="pull-right label {{ metric_bg('v3', 'S', cvss.scope) }}">{{ cvss.scope }}</span>
                    </h4>
                </div>
            </div>
        </div>
    </div>
</div>