{% extends "base.html" %}

{% block content %}
{% from "_macros.html" import render_field %}
{% from "flask_user/_macros.html" import render_submit_field %}

<div class="row">
    <div class="col-sm-12">
        <div class="profile-picture"
             style="background-image:url('{{ url_for('static', filename='img/deep-green.jpg') }}')">
            <img src="{{ current_user.email | gravatar(size=88) }}" class="thumb-lg img-circle img-thumbnail"
                 alt="profile-image">
            <h3>{{ current_user.username }}</h3>
        </div>
    </div>
</div>

<div class="row">
    <div class="col-sm-12">
        <div class="nav-tabs-custom nav-tabs-profile nav-tabs-primary">
            <ul class="nav nav-tabs">
                <li class="{% if is_active('main.subscriptions') %}active{% endif %}">
                    <a href="{{ url_for('main.subscriptions') }}">Subscriptions</a>
                </li>
                <li class="{% if is_active('main.tags,main.edit_tag,main.delete_tag') %}active{% endif %}">
                    <a href="{{ url_for('main.tags') }}">Tags</a>
                </li>
                <li class="{% if is_active('main.notifications') %}active{% endif %}">
                    <a href="{{ url_for('main.notifications') }}">Notifications</a>
                </li>
                <li class="{% if is_active('main.settings,user.edit_user_profile,user.change_password') %}active{% endif %}">
                    <a href="{{ url_for('user.edit_user_profile') }}">Settings</a>
                </li>
            </ul>
        </div>
    </div>
</div>

<section class="content">
    <div class="row">
        <div class="col-md-12">
            {% include 'messages.html' %}
            {% block content_profile %}{% endblock %}
        </div>
    </div>
</section>

{% endblock %}
