<!--
Licensed under MIT (https://github.com/charlesmudy/Respmail/blob/master/LICENSE)
Designed by Shina Charles Memud
Respmail v1.1 (http://charlesmudy.com/respmail/)
-->
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
    <meta name="viewport" content="width=device-width,initial-scale=1">
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
    <meta name="format-detection" content="telephone=no"> <!-- disable auto telephone linking in iOS -->
    <title>{{ subject }}</title>
    <style type="text/css">
                    /* RESET STYLES */
                    body, #bodyTable, #bodyCell, #bodyCell{height:100% !important; margin:0; padding:0; width:100% !important;font-family:Helvetica, Arial, "Lucida Grande", sans-serif;}
                    table{border-collapse:collapse;}
                    table[id=bodyTable] {width:100%!important;margin:auto;max-width:500px!important;color:#7A7A7A;font-weight:normal;}
                    img, a img{border:0; outline:none; text-decoration:none;height:auto; line-height:100%;}
                    a {text-decoration:none !important;border-bottom: 1px solid;}
                    h1, h2, h3, h4, h5, h6{color:#5F5F5F; font-weight:normal; font-family:Helvetica; font-size:20px; line-height:125%; text-align:Left; letter-spacing:normal;margin-top:0;margin-right:0;margin-bottom:10px;margin-left:0;padding-top:0;padding-bottom:0;padding-left:0;padding-right:0;}

                    /* CLIENT-SPECIFIC STYLES */
                    .ReadMsgBody{width:100%;} .ExternalClass{width:100%;} /* Force Hotmail/Outlook.com to display emails at full width. */
                    .ExternalClass, .ExternalClass p, .ExternalClass span, .ExternalClass font, .ExternalClass td, .ExternalClass div{line-height:100%;} /* Force Hotmail/Outlook.com to display line heights normally. */
                    table, td{mso-table-lspace:0pt; mso-table-rspace:0pt;} /* Remove spacing between tables in Outlook 2007 and up. */
                    #outlook a{padding:0;} /* Force Outlook 2007 and up to provide a "view in browser" message. */
                    img{-ms-interpolation-mode: bicubic;display:block;outline:none; text-decoration:none;} /* Force IE to smoothly render resized images. */
                    body, table, td, p, a, li, blockquote{-ms-text-size-adjust:100%; -webkit-text-size-adjust:100%; font-weight:normal!important;} /* Prevent Windows- and Webkit-based mobile platforms from changing declared text sizes. */
                    .ExternalClass td[class="ecxflexibleContainerBox"] h3 {padding-top: 10px !important;} /* Force hotmail to push 2-grid sub headers down */

                    /* /\/\/\/\/\/\/\/\/ TEMPLATE STYLES /\/\/\/\/\/\/\/\/ */

                    /* ========== Page Styles ========== */
                    h1{display:block;font-size:26px;font-style:normal;font-weight:normal;line-height:100%;}
                    h2{display:block;font-size:20px;font-style:normal;font-weight:normal;line-height:120%;}
                    h3{display:block;font-size:17px;font-style:normal;font-weight:normal;line-height:110%;}
                    h4{display:block;font-size:18px;font-style:italic;font-weight:normal;line-height:100%;}
                    .flexibleImage{height:auto;}
                    .linkRemoveBorder{border-bottom:0 !important;}
                    table[class=flexibleContainerCellDivider] {padding-bottom:0 !important;padding-top:0 !important;}

                    body, #bodyTable{background-color:#E1E1E1;}
                    #emailHeader{background-color:#E1E1E1;}
                    #emailBody{background-color:#FFFFFF;}
                    #emailFooter{background-color:#E1E1E1;}
                    .textContent, .textContentLast{color:#8B8B8B; font-family:Helvetica; font-size:14px; line-height:125%; text-align:Left;}
                    .textContent a, .textContentLast a{color:#205478; text-decoration:underline;}
                    .nestedContainer{background-color:#F8F8F8; border:1px solid #CCCCCC;}
                    .emailButton{background-color:#205478; border-collapse:separate;}
                    .buttonContent{color:#FFFFFF; font-family:Helvetica; font-size:18px; font-weight:bold; line-height:100%; padding:15px; text-align:center;}
                    .buttonContent a{color:#FFFFFF; display:block; text-decoration:none!important; border:0!important;}
                    .emailCalendar{background-color:#FFFFFF; border:1px solid #CCCCCC;}
                    .emailCalendarMonth{background-color:#205478; color:#FFFFFF; font-family:Helvetica, Arial, sans-serif; font-size:14px; font-weight:bold; padding-top:10px; padding-bottom:10px; text-align:center;}
                    .emailCalendarDay{color:#205478; font-family:Helvetica, Arial, sans-serif; font-size:60px; font-weight:bold; line-height:100%; padding-top:20px; padding-bottom:20px; text-align:center;}
                    .imageContentText {margin-top: 10px;line-height:0;}
                    .imageContentText a {line-height:0;}
                    #invisibleIntroduction {display:none !important;} /* Removing the introduction text from the view */

                    /*FRAMEWORK HACKS & OVERRIDES */
                    span[class=ios-color-hack] a {color:#275100!important;text-decoration:none!important;} /* Remove all link colors in IOS (below are duplicates based on the color preference) */
                    span[class=ios-color-hack2] a {color:#205478!important;text-decoration:none!important;}
                    span[class=ios-color-hack3] a {color:#8B8B8B!important;text-decoration:none!important;}
                    /* A nice and clean way to target phone numbers you want clickable and avoid a mobile phone from linking other numbers that look like, but are not phone numbers.  Use these two blocks of code to "unstyle" any numbers that may be linked.  The second block gives you a class to apply with a span tag to the numbers you would like linked and styled.
                    Inspired by Campaign Monitor's article on using phone numbers in email: http://www.campaignmonitor.com/blog/post/3571/using-phone-numbers-in-html-email/.
                    */
                    .a[href^="tel"], a[href^="sms"] {text-decoration:none!important;color:#606060!important;pointer-events:none!important;cursor:default!important;}
                    .mobile_link a[href^="tel"], .mobile_link a[href^="sms"] {text-decoration:none!important;color:#606060!important;pointer-events:auto!important;cursor:default!important;}


                    /* MOBILE STYLES */
                    @media only screen and (max-width: 480px){
                        /*////// CLIENT-SPECIFIC STYLES //////*/
                        body{width:100% !important; min-width:100% !important;} /* Force iOS Mail to render the email at full width. */

                        /* FRAMEWORK STYLES */
                        /*
                            CSS selectors are written in attribute
                            selector format to prevent Yahoo Mail
                            from rendering media query styles on
                            desktop.
                        */
                        table[id="emailHeader"], table[id="emailBody"], table[id="emailFooter"], table[class="flexibleContainer"] {width:100% !important;}
                        td[class="flexibleContainerBox"], td[class="flexibleContainerBox"] table {display: block;width: 100%;text-align: left;}
                        /*
                            The following style rule makes any
                            image classed with 'flexibleImage'
                            fluid when the query activates.
                            Make sure you add an inline max-width
                            to those images to prevent them
                            from blowing out.
                        */
                        td[class="imageContent"] img {height:auto !important; width:100% !important; max-width:100% !important;}
                        img[class="flexibleImage"]{height:auto !important; width:100% !important;max-width:100% !important;}
                        img[class="flexibleImageSmall"]{height:auto !important; width:auto !important;}


                        /*
                            Create top space for every second element in a block
                        */
                        table[class="flexibleContainerBoxNext"]{padding-top: 10px !important;}

                        /*
                            Make buttons in the email span the
                            full width of their container, allowing
                            for left- or right-handed ease of use.
                        */
                        table[class="emailButton"]{width:100% !important;}
                        td[class="buttonContent"]{padding:0 !important;}
                        td[class="buttonContent"] a{padding:15px !important;}

                    }

                    /*  CONDITIONS FOR ANDROID DEVICES ONLY
                    *   http://developer.android.com/guide/webapps/targeting.html
                    *   http://pugetworks.com/2011/04/css-media-queries-for-targeting-different-mobile-devices/ ;
                    =====================================================*/

                    @media only screen and (-webkit-device-pixel-ratio:.75){
                        /* Put CSS for low density (ldpi) Android layouts in here */
                    }

                    @media only screen and (-webkit-device-pixel-ratio:1){
                        /* Put CSS for medium density (mdpi) Android layouts in here */
                    }

                    @media only screen and (-webkit-device-pixel-ratio:1.5){
                        /* Put CSS for high density (hdpi) Android layouts in here */
                    }
                    /* end Android targeting */

                    /* CONDITIONS FOR IOS DEVICES ONLY
                    =====================================================*/
                    @media only screen and (min-device-width : 320px) and (max-device-width:568px) {

                    }
                    /* end IOS targeting */


    </style>
    <!--[if mso 12]>
    <style type="text/css">
                        .flexibleContainer{display:block !important; width:100% !important;}


    </style>
    <![endif]-->
    <!--[if mso 14]>
    <style type="text/css">
                        .flexibleContainer{display:block !important; width:100% !important;}


    </style>
    <![endif]-->
</head>
<body bgcolor="#E1E1E1" leftmargin="0" marginwidth="0" topmargin="0" marginheight="0" offset="0">
<center style="background-color:#E1E1E1">
    <table border="0" cellpadding="0" cellspacing="0" height="100%" width="100%" id="bodyTable"
           style="table-layout: fixed;max-width:100% !important;width: 100% !important;min-width: 100% !important">
        <tr>
            <td align="center" valign="top" id="bodyCell">
                <table bgcolor="#E1E1E1" border="0" cellpadding="0" cellspacing="0" width="600" id="emailHeader">

                    <tr>
                        <td align="center" valign="top">
                            <table border="0" cellpadding="0" cellspacing="0" width="100%">
                                <tr>
                                    <td align="center" valign="top">
                                        <table border="0" cellpadding="10" cellspacing="0" width="600"
                                               class="flexibleContainer">
                                            <tr>
                                                <td valign="top" width="600" class="flexibleContainerCell"></td>
                                            </tr>
                                        </table>
                                    </td>
                                </tr>
                            </table>
                        </td>
                    </tr>

                </table>

                <table bgcolor="#FFFFFF" border="0" cellpadding="0" cellspacing="0" width="600" id="emailBody">

                    <tr>
                        <td align="center" valign="top">
                            <table border="0" cellpadding="0" cellspacing="0" width="100%" style="color:#FFFFFF;"
                                   bgcolor="#2b4049">
                                <tr>
                                    <td align="center" valign="top">
                                        <table border="0" cellpadding="0" cellspacing="0" width="600"
                                               class="flexibleContainer">
                                            <tr>
                                                <td align="center" valign="top" width="600"
                                                    class="flexibleContainerCell">
                                                    <table border="0" cellpadding="20" cellspacing="0" width="100%">
                                                        <tr>
                                                            <td align="center">
                                                                <img title="OpenCVE" alt="Text" style="max-width:100%;"
                                                                     class="flexibleImageSmall"
                                                                     src="{{ url_for('main.static', filename='img/mail_icon.png', _external=True) }}">
                                                            </td>
                                                        </tr>
                                                    </table>
                                                </td>
                                            </tr>
                                        </table>
                                    </td>
                                </tr>
                            </table>
                        </td>
                    </tr>

                    <tr>
                        <td valign="top" align="center">
                            <table width="100%" cellspacing="0" cellpadding="0" border="0">
                                <tbody>
                                <tr>
                                    <td valign="top" align="center">
                                        <table width="600" cellspacing="0" cellpadding="24" border="0"
                                               class="flexibleContainer" bgcolor="#F8F8F8">
                                            <tbody>
                                            <tr>
                                                <td width="600" valign="top" class="flexibleContainerCell">
                                                    <table width="100%" cellspacing="0" cellpadding="0" border="0"
                                                           align="left">
                                                        <tbody>
                                                        <tr>
                                                            <td valign="middle" align="right"
                                                                class="flexibleContainerBox">
                                                                <table width="540" cellspacing="0" cellpadding="0"
                                                                       border="0" style="max-width:100%;"
                                                                       class="flexibleContainerBoxNext">
                                                                    <tbody>
                                                                    <tr>
                                                                        <td align="left" class="textContent">
                                                                            {% if total_alerts > 10 %}
                                                                            <div style="text-align:center;font-family:Helvetica,Arial,sans-serif;font-size:17px;margin-bottom:0;color:#5F5F5F;line-height:135%;">
                                                                                Top 10 of {{ total_alerts }} alerts
                                                                                (view the <a
                                                                                    style="text-decoration:none;border-bottom:1px solid #828282;color:#828282;"
                                                                                    target="_blank"
                                                                                    href="{{ url_for('main.report', link=report_public_link, _external=True) }}"><span
                                                                                    style="color:#828282;">full report</span></a>).
                                                                            </div>
                                                                            {% else %}
                                                                            <div style="text-align:center;font-family:Helvetica,Arial,sans-serif;font-size:17px;margin-bottom:0;color:#5F5F5F;line-height:135%;">
                                                                                View the <a
                                                                                    style="text-decoration:none;border-bottom:1px solid #828282;color:#828282;"
                                                                                    target="_blank"
                                                                                    href="{{ url_for('main.report', link=report_public_link, _external=True) }}"><span
                                                                                    style="color:#828282;">full report</span></a>.
                                                                            </div>
                                                                            {% endif %}
                                                                        </td>
                                                                    </tr>
                                                                    </tbody>
                                                                </table>
                                                            </td>
                                                        </tr>
                                                        </tbody>
                                                    </table>
                                                </td>
                                            </tr>
                                            </tbody>
                                        </table>
                                    </td>
                                </tr>
                                </tbody>
                            </table>
                        </td>
                    </tr>

                    {% for key, alerts in alerts_sorted.items() %}
                    <tr>
                        <td align="center" valign="top">
                            <table border="0" cellpadding="0" cellspacing="0" width="100%" bgcolor="#F4F4F4"
                                   style="border-top:1px solid #C8C8C8;">
                                <tr>
                                    <td align="center" valign="top">
                                        <table border="0" cellpadding="0" cellspacing="0" width="600"
                                               class="flexibleContainer">
                                            <tr>
                                                <td align="center" valign="top" width="500"
                                                    class="flexibleContainerCell">
                                                    <table border="0" cellpadding="20" cellspacing="0" width="100%">
                                                        <tr>
                                                            <td align="center" valign="top">
                                                                <table border="0" cellpadding="0" cellspacing="0"
                                                                       width="100%">
                                                                    <tr>
                                                                        <td valign="top" class="textContent">
                                                                            <h3 style="color:#5F5F5F;line-height:100%;font-family:Helvetica,Arial,sans-serif;font-size:20px;font-weight:normal;margin-top:0;margin-bottom:3px;">
                                                                                {{ alerts.name }}
                                                                            </h3>
                                                                        </td>
                                                                    </tr>
                                                                </table>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                </td>
                                            </tr>
                                        </table>
                                    </td>
                                </tr>
                            </table>
                        </td>
                    </tr>
                    {% for alert in alerts.alerts|sort(reverse=True, attribute='cve.cvss_weight') %}
                    <tr>
                        <td align="center" valign="top">
                            <table border="0" cellpadding="0" cellspacing="0" width="100%">
                                <tr>
                                    <td align="center" valign="top">
                                        <table border="0" cellpadding="0" cellspacing="0" width="600"
                                               class="flexibleContainer">
                                            <tr>
                                                <td align="center" valign="top" width="600"
                                                    class="flexibleContainerCell" style="padding: 15px 20px;">
                                                    <table border="0" cellpadding="0" cellspacing="0" width="100%">
                                                        <tr>
                                                            <td align="center" valign="top">
                                                                <table border="0" cellpadding="0" cellspacing="0"
                                                                       width="100%">
                                                                    <tr>
                                                                        <td valign="top" class="textContent">
                                                                            <h3 style="color:#5F5F5F;line-height:125%;font-family:Helvetica,Arial,sans-serif;font-size:16px;font-weight:normal;margin-top:0;margin-bottom:6px;text-align:left">
                                                                                <a href="{{ url_for('main.cve', cve_id=alert.cve.cve_id, _external=True) }}">{{
                                                                                    alert.cve.cve_id }}</a> - {% if
                                                                                alert.cve.cvss3 %}<span
                                                                                    style="color:{% if alert.cve.cvss3 >= 9.0 %}#972b1e{% elif alert.cve.cvss3 >= 7%}#ef5350{% elif alert.cve.cvss3 >= 4%}#f49841{% else %}#2b9ac9{% endif %}">{{ alert.cve.cvss3 }}</span>{%
                                                                                else %}<span style="color: gray;">No CVSS v3</span>{%
                                                                                endif %}</h3>
                                                                            <p>{{ alert.cve.summary|truncate(230) }}</p>
                                                                            {% if alert.events|length > 0 %}
                                                                            <div style="text-align:left;font-family:Helvetica,Arial,sans-serif;font-size:15px;color:#5F5F5F;line-height:135%">
                                                                                <strong>Change{% if alert.events|length
                                                                                    > 1 %}s{% endif %} :</strong> {% for
                                                                                event in alert.events %}<i>{{
                                                                                event.type.value }}</i>{% if not
                                                                                loop.last %}, {% endif %}{% endfor %}
                                                                            </div>
                                                                            {% endif %}
                                                                        </td>
                                                                    </tr>
                                                                </table>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                </td>
                                            </tr>
                                        </table>
                                    </td>
                                </tr>
                            </table>
                        </td>
                    </tr>
                    {% endfor %}
                    {% endfor %}

                    <tr>
                        <td valign="top" align="center">
                            <table width="100%" cellspacing="0" cellpadding="0" border="0">
                                <tbody>
                                <tr style="padding-top:0;">
                                    <td valign="top" align="center">
                                        <table width="600" cellspacing="0" cellpadding="30" border="0"
                                               class="flexibleContainer">
                                            <tbody>
                                            <tr>
                                                <td width="600" valign="top" align="center"
                                                    class="flexibleContainerCell" style="border-top:1px solid #c8c8c8;">
                                                    <table width="50%" cellspacing="0" cellpadding="0" border="0"
                                                           style="background-color: #2b4049;" class="emailButton">
                                                        <tbody>
                                                        <tr>
                                                            <td valign="middle" align="center"
                                                                style="padding-top:15px;padding-bottom:15px;padding-right:15px;padding-left:15px;"
                                                                class="buttonContent">
                                                                <a target="_blank"
                                                                   href="{{ url_for('main.report', link=report_public_link, _external=True) }}"
                                                                   style="color:#FFFFFF;text-decoration:none;font-family:Helvetica,Arial,sans-serif;font-size:20px;line-height:135%;">►
                                                                    View the full report</a>
                                                            </td>
                                                        </tr>
                                                        </tbody>
                                                    </table>

                                                </td>
                                            </tr>
                                            </tbody>
                                        </table>
                                    </td>
                                </tr>
                                </tbody>
                            </table>
                        </td>
                    </tr>

                    <tr>
                        <td valign="top" align="center">
                            <!-- CENTERING TABLE // -->
                            <table width="100%" cellspacing="0" cellpadding="0" border="0" bgcolor="#2b4049">
                                <tbody>
                                <tr>
                                    <td valign="top" align="center">
                                        <!-- FLEXIBLE CONTAINER // -->
                                        <table width="600" cellspacing="0" cellpadding="0" border="0"
                                               class="flexibleContainer">
                                            <tbody>
                                            <tr>
                                                <td width="600" valign="top" align="center"
                                                    class="flexibleContainerCell">
                                                    <table width="100%" cellspacing="0" cellpadding="20" border="0">
                                                        <tbody>
                                                        <tr>
                                                            <td valign="top" align="center">

                                                                <!-- CONTENT TABLE // -->
                                                                <table width="100%" cellspacing="0" cellpadding="0"
                                                                       border="0">
                                                                    <tbody>
                                                                    <tr>
                                                                        <td valign="top" class="textContent">
                                                                            <div style="text-align:center;font-family:Helvetica,Arial,sans-serif;font-size:15px;margin-bottom:0;margin-top:3px;color:#5F5F5F;line-height:135%;">
                                                                                <a style="color:#ffffff;"
                                                                                   target="_blank"
                                                                                   href="https://twitter.com/opencve">Follow
                                                                                    OpenCVE on Twitter</a></div>
                                                                        </td>
                                                                    </tr>
                                                                    </tbody>
                                                                </table>
                                                                <!-- // CONTENT TABLE -->

                                                            </td>
                                                        </tr>
                                                        </tbody>
                                                    </table>
                                                </td>
                                            </tr>
                                            </tbody>
                                        </table>
                                        <!-- // FLEXIBLE CONTAINER -->
                                    </td>
                                </tr>
                                </tbody>
                            </table>
                            <!-- // CENTERING TABLE -->
                        </td>
                    </tr>
                </table>
                <!-- // END -->

                <!-- EMAIL FOOTER // -->
                <!--
                    The table "emailBody" is the email's container.
                    Its width can be set to 100% for a color band
                    that spans the width of the page.
                -->
                <table bgcolor="#E1E1E1" border="0" cellpadding="0" cellspacing="0" width="600" id="emailFooter">

                    <!-- FOOTER ROW // -->
                    <!--
                        To move or duplicate any of the design patterns
                        in this email, simply move or copy the entire
                        MODULE ROW section for each content block.
                    -->
                    <tr>
                        <td align="center" valign="top">
                            <!-- CENTERING TABLE // -->
                            <table border="0" cellpadding="0" cellspacing="0" width="100%">
                                <tr>
                                    <td align="center" valign="top">
                                        <!-- FLEXIBLE CONTAINER // -->
                                        <table border="0" cellpadding="0" cellspacing="0" width="600"
                                               class="flexibleContainer">
                                            <tr>
                                                <td align="center" valign="top" width="600"
                                                    class="flexibleContainerCell">
                                                    <table border="0" cellpadding="20" cellspacing="0" width="100%">
                                                        <tr>
                                                            <td valign="top" bgcolor="#E1E1E1">

                                                                <div style="font-family:Helvetica,Arial,sans-serif;font-size:13px;color:#828282;text-align:center;line-height:120%">
                                                                    <div>Copyright &#169; 2021 <a
                                                                            href="https://opencve.io" target="_blank"
                                                                            style="text-decoration:none;color:#828282"><span
                                                                            style="color:#828282">OpenCVE.io</span></a>.
                                                                        All&nbsp;rights&nbsp;reserved.
                                                                    </div>
                                                                    <div>If you do not want to receive emails, you can
                                                                        unsubscribe <a
                                                                                href="{{ url_for('main.notifications', _external=True) }}"
                                                                                target="_blank"
                                                                                style="text-decoration:none;color:#828282"><span
                                                                                style="color:#828282">here</span></a>.
                                                                    </div>
                                                                </div>

                                                            </td>
                                                        </tr>
                                                    </table>
                                                </td>
                                            </tr>
                                        </table>
                                        <!-- // FLEXIBLE CONTAINER -->
                                    </td>
                                </tr>
                            </table>
                            <!-- // CENTERING TABLE -->
                        </td>
                    </tr>

                </table>
                <!-- // END -->

            </td>
        </tr>
    </table>
</center>
</body>
</html>
