{% extends 'base_welcome.html' %}
{% block title %}{{ super() }}{% endblock %}

{% block content %}

<main role="main" class="container">

    <div class="starter-template">
        <img src="{{ url_for('static', filename='img/logo_full_48.png') }}" alt="Logo">
        <h1>Welcome to OpenCVE</h1>
        <p class="lead">
            Start to explore the list of <a href="{{ url_for('main.cves') }}">CVE</a> or find it using <a
                href="{{ url_for('main.vendors') }}">Vendors</a>.
            <br>
            Connect you <a href="{{ url_for('user.login') }}">here</a> to display CVE based on your subscriptions.
        </p>
    </div>

</main>

{% endblock %}
