{% extends "base.html" %}

{% block title %}404 Not Found - {{ super() }}{% endblock %}

{% block content %}

<section class="content">
    <div class="error-page">
        <h2 class="headline">404</h2>
        <div class="error-content">
            <h3><i class="fa  fa-exclamation-triangle"></i> Page not found</h3>
            <p>The page you are looking was not found. Click <a href="">here</a> to be redirected to the homepage.</p>
        </div>
    </div>
</section>

{% endblock %}