<tr>
    {% if not hide_type %}
    <td>First Time</td>
    {% endif %}
    <td></td>
    <td>
        {% for item in event.details %}
        {{ item|remove_product_separator|humanize }}
        <br />
        {% endfor %}
    </td>
</tr>
