{% if event.details["removed"] or event.details["added"] %}
<tr>
    {% if not hide_type %}
    <td>References</td>
    {% endif %}
    <td>
        {% if event.details["removed"] %}
        <ul>{% for ref in event.details["removed"] %}
            <li><s>{{ ref }}</s></li>
            {% endfor %}
        </ul>
        {% endif %}
    </td>
    <td>
        {% if event.details["added"] %}
        <ul>
            {% for ref in event.details["added"] %}
            <li>({{ ref.refsource }}) {{ ref.url }} - {{ ref.tags|join(', ') }}</li>
            {% endfor %}
        </ul>
        {% endif %}
    </td>
</tr>
{% endif %}

{% for ref in event.details["changed"] %}
<tr>
    {% if not hide_type %}
    <td>References</td>
    {% endif %}
    <td><s>({{ ref.old.refsource }}) {{ ref.old.url }} - {{ ref.old.tags|join(', ') }}</s></td>
    <td>({{ ref.new.refsource }}) {{ ref.new.url }} - {{ ref.new.tags|join(', ') }}</td>
</tr>
{% endfor %}